@@ -8,6 +8,7 @@ from datetime import datetime
 import os.path
 from shutil import copyfile, move
 from socket import gethostname
+from warnings import warn
 
 from django.utils.datastructures import SortedDict
 from PIL import Image
@@ -134,29 +135,43 @@ def build_modelgraph(docs_path, package_name="mezzanine"):
     package name, generates a smaller version and add it to the
     docs directory for use in model-graph.rst
     """
-    project_path = os.path.join(docs_path, "..", package_name,
-                                "project_template")
+    to_path = os.path.join(docs_path, "img", "graph.png")
+    build_path = os.path.join(docs_path, "build", "_images")
+    resized_path = os.path.join(os.path.dirname(to_path), "graph-small.png")
     settings = import_dotted_path(package_name + ".project_template.settings")
     apps = [a.rsplit(".")[1] for a in settings.INSTALLED_APPS
             if a.startswith("mezzanine.") or a.startswith(package_name + ".")]
-    os.chdir(project_path)
-    cmd = "python manage.py graph_models -e -o graph.png %s" % " ".join(apps)
-    os.system(cmd)
-    to_path = os.path.join(docs_path, "img", "graph.png")
-    move(os.path.join(project_path, "graph.png"), to_path)
-    build_path = os.path.join(docs_path, "build", "_images")
-    if not os.path.exists(build_path):
-        os.makedirs(build_path)
     try:
+        from django_extensions.management.commands import graph_models
+    except ImportError:
+        warn("Couldn't build model_graph, django_extensions not installed")
+    else:
+        options = {"inheritance": True, "outputfile": "graph.png",
+                  "layout": "dot"}
+        try:
+            graph_models.Command().execute(*apps, **options)
+        except Exception, e:
+            warn("Couldn't build model_graph, graph_models failed on: %s" % e)
+        else:
+            try:
+                move("graph.png", to_path)
+            except OSError, e:
+                warn("Couldn't build model_graph, move failed on: %s" % e)
+    # docs/img/graph.png should exist in the repo - move it to the build path.
+    try:
+        if not os.path.exists(build_path):
+            os.makedirs(build_path)
         copyfile(to_path, os.path.join(build_path, "graph.png"))
-    except IOError, e:
-        import warnings
-        warnings.warn("Couldn't build model graph: %s" % e)
-    image = Image.open(to_path)
-    image.width = 800
-    image.height = image.size[1] * 800 / image.size[0]
-    resized_path = os.path.join(os.path.dirname(to_path), "graph-small.png")
-    image.save(resized_path, "PNG", quality=100)
+    except OSError, e:
+        warn("Couldn't build model_graph, copy to build failed on: %s" % e)
+    try:
+        image = Image.open(to_path)
+        image.width = 800
+        image.height = image.size[1] * 800 / image.size[0]
+        image.save(resized_path, "PNG", quality=100)
+    except Exception, e:
+        warn("Couldn't build model_graph, resize failed on: %s" % e)
+        return
 
 
 def build_requirements(docs_path, package_name="mezzanine"):
